# Analyses (R code by Koppensteiner M.)
# "Speaking one's mind through one's body"
# "The voice body motion link."
# by Koppensteiner

#setwd(getwd())
setwd("C:\\ALLMYSTUFF\\Poltics&LifeSciences\\REVISION\\NextStepAnalyses\\")


###########   Experiment   ##############
########### matching body motion and voice ##########

## LOADING data.frame

library(lme4)# also contains nlme
library(yhat)


matching_dat <-read.table("Matching_Voice_Stickfigure.txt", header = T, sep = "\t")
names(matching_dat)


# get age of raters and their sex 
filtered_dat <- aggregate(x = matching_dat[,c("age","sex_m1_f0")], by = list(matching_dat$rater), FUN = mean)
filtered_dat

# average age of raters (plus standard deviation)
round(mean(filtered_dat$age),2)
round(sd(filtered_dat$age),2)
# extra range
round(max(filtered_dat$age),2)
round(min(filtered_dat$age),2)

# number of male and female raters // 0 are females ; and 1 are males
all_raters <- length(filtered_dat$sex_m1_f0)
male_raters <- sum(filtered_dat$sex_m1_f0) 
fem_raters <- all_raters - male_raters
all_raters
male_raters
fem_raters

# overall correct answers
overall_sample_size <- length(matching_dat$corr1_wrong0)
overall_corr <- sum(matching_dat$corr1_wrong0)
overall_wrong <-  overall_sample_size - overall_corr
overall_corr
overall_wrong 

# binomial test; probability to get such a result; ATTENTION: independent data
overall_binom <- binom.test(x = c(overall_corr,overall_wrong),n = overall_sample_size, p =0.2)
overall_binom # returns probility of success  b




# number of correct matches (video with voice) per rater
correct_dat <- aggregate(x = matching_dat[,c("corr1_wrong0")], by = list(matching_dat$rater), FUN = sum)
correct_dat

raters_num <- length(levels(matching_dat$rater))
# descriptive statistics of matches per rater
max(correct_dat$x)
min(correct_dat$x)
median(correct_dat$x) 

# mean is above random choice, 5 choices per round and 15 rounds
# makes a probability of 1/5 * 15  => 3 random correct answers 

binom.test(x =c(6,8),n = 15,p = 0.2) #-> p = 0.02 -> >= 6 is significant at 0.05 level
# how many raters have 7 or more correct answers
above_sig <- correct_dat[ correct_dat$x >= 6, 2]
how_many_above_sig <- length(above_sig)
how_many_above_sig

# frequencies of correct answers/rater
table(correct_dat$x)


# counting how often a certain stick-figure was rated and correctly identified

stim_correct <- aggregate(x = matching_dat[,c("corr1_wrong0")], by = list(matching_dat$video_rec), FUN = sum)
stim_correct
stim_num_rated <- as.data.frame(table(matching_dat$video_rec))
stim_num_rated
median(stim_num_rated$Freq)

merge_dats <- merge(x = stim_correct, y =stim_num_rated,  by.x = "Group.1",
                    by.y = "Var1")
merge_dats

# determining how often voice and body motion has been correctly matched for each stimulus
rel_correct_stim <- merge_dats$x/merge_dats$Freq
merge_dats <- cbind(merge_dats ,rel_correct_stim )

merge_dats

#descriptive statistics for recogition rate
mean(merge_dats$rel_correct_stim)
sd(merge_dats$rel_correct_stim)
max(merge_dats$rel_correct_stim)
min(merge_dats$rel_correct_stim)

# how many videos were never classified correctly
sum(merge_dats$rel_correct_stim== 0)
# how many were classified correctly every time 
sum(merge_dats$rel_correct_stim == 1)

# 2) Analyze relationship of number correct classifications with loudness and expansiveness of motion
nonverbal_measures <-read.table("Nonverbal_Measures.txt", header = T, sep = "\t")
names(nonverbal_measures)

mean(nonverbal_measures$ampli_average)
sd(nonverbal_measures$ampli_average)

mean(nonverbal_measures$vol_average)
sd(nonverbal_measures$vol_average)


# correlations between vol_average and ampli_average with percentage measure of
# correctly identified voices (how often was corrsponding voice assigned to stick-figure)
cor.test(nonverbal_measures$vol_average,nonverbal_measures$perc_corr)
cor.test(nonverbal_measures$ampli_average,nonverbal_measures$perc_corr)

# correlation between average volume and average overall amplitude
cor.test(nonverbal_measures$vol_average,nonverbal_measures$ampli_average)

red_nonverbal_measures <- nonverbal_measures[, c("vol_average","ampli_average","perc_corr")]
z_nonverbal_measures <- as.data.frame(scale(red_nonverbal_measures))


# regression analyses with relative weights to track down relative contribution of independent variables
mod_out <- lm(perc_corr ~ vol_average + ampli_average, data = z_nonverbal_measures)

summary(mod_out)

round(mod_out$coefficients, 2)

# calculating realtive weights which give the relative proportion explained by each weight 
rlw_out <- rlw(z_nonverbal_measures,"perc_corr",c("vol_average","ampli_average"))
rlw_out 


mod_out_single <- lm(perc_corr ~ vol_average, data = z_nonverbal_measures)
summary(mod_out_single) 
mod_out_singleII <- lm(perc_corr ~ ampli_average, data = z_nonverbal_measures)
summary(mod_out_singleII) 

# 3) Analyze whether wrong classifications show a relationship between 
#    volume and amplitude of body motion
wrongly_classified_dat <-read.table("Wrong_Associate.txt", header = T, sep = "\t")
names(wrongly_classified_dat)

z_wrongly_classified <- as.data.frame(scale(wrongly_classified_dat[,c("vol_wrong","ampli_corr")]))
# add column rater_num to new data frame
z_wrongly_classified$rater_num <- wrongly_classified_dat$rater_num
# test whether there is a relationship between amplitude (expressive motion) of the stick-figures (ampli_corr)
# and the volume (loudness of voice) of the wrongly assigned voices (vol_wrong)
# when people simply assign expressiveness of motion with loudness of voice there should be a noteworthy correlation
res_cor <- cor.test(wrongly_classified_dat$vol_wrong, wrongly_classified_dat$ampli_corr)
res_cor
# t <-res_cor$statistic
#2*pt(-abs(t),df=64-2) #p-value two sided 

# do the same using a mixed model analyses (using one of the variables as predictor) # bootstrap???
# in an regression with z-tranformed data and one predictor only the beta wieght is equal to a correlation coefficient
mix_rel_stick_voice <- lmer(ampli_corr ~ vol_wrong + (1|rater_num), data = z_wrongly_classified)
summary(mix_rel_stick_voice)



